Changelog
=========

1.0.1 (2017-01-06)
------------------

- Fix sortable title lookup for wiki pages
  [vangheem]

1.0.0 (2017-01-03)
------------------

- documentation
  [tkimnguyen]

- initial release
  [vangheem]
